# Contributing

Welcome! As a [Jupyter](https://jupyter.org) project, we follow the [Jupyter contributor guide](https://jupyter.readthedocs.io/en/latest/contributor/content-contributor.html).

To set up a development environment for this repository:

1. Clone this repository:

        git clone https://github.com/jupyterhub/oauthenticator

2. Do a development install with pip:

        cd oauthenticator
        pip install -e .

